# Copyright 2017 Google Inc.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# ----------------------------------------------------------------------------
#
#     ***     AUTO GENERATED CODE    ***    AUTO GENERATED CODE     ***
#
# ----------------------------------------------------------------------------
#
#     This file is automatically generated by puppet-codegen and manual
#     changes will be clobbered when the file is regenerated.
#
#     Please read more about how to change this file in README.md and
#     CONTRIBUTING.md located at the root of this package.
#
# ----------------------------------------------------------------------------

require 'google/compute/property/integer'
require 'google/compute/property/string'
require 'google/compute/property/time'
require 'puppet'

Puppet::Type.newtype(:gcompute_http_health_check) do
  @doc = <<-EOT
    An HttpHealthCheck resource. This resource defines a template for how
    individual VMs should be checked for health, via HTTP.
  EOT

  autorequire(:gauth_credential) do
    [self[:credential]]
  end

  ensurable

  newparam :credential do
    desc <<-EOT
      A gauth_credential name to be used to authenticate with Google Cloud
      Platform.
    EOT
  end

  newparam(:project) do
    desc 'A Google Cloud Platform project to manage.'
  end

  newparam(:name, namevar: true) do
    # TODO(nelsona): Make this description to match the key of the object.
    desc 'The name of the HttpHealthCheck.'
  end

  newproperty(:check_interval_sec,
              parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      How often (in seconds) to send a health check. The default value is 5
      seconds.
    EOT
  end

  newproperty(:creation_timestamp, parent: Google::Compute::Property::Time) do
    desc 'Creation timestamp in RFC3339 text format. (output only)'
  end

  newproperty(:description, parent: Google::Compute::Property::String) do
    desc <<-EOT
      An optional description of this resource. Provide this property when you
      create the resource.
    EOT
  end

  newproperty(:healthy_threshold, parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      A so-far unhealthy instance will be marked healthy after this many
      consecutive successes. The default value is 2.
    EOT
  end

  newproperty(:host, parent: Google::Compute::Property::String) do
    desc <<-EOT
      The value of the host header in the HTTP health check request. If left
      empty (default value), the public IP on behalf of which this health check
      is performed will be used.
    EOT
  end

  newproperty(:id, parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      The unique identifier for the resource. This identifier is defined by the
      server. (output only)
    EOT
  end

  newproperty(:name, parent: Google::Compute::Property::String) do
    desc <<-EOT
      Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the regular
      expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character
      must be a lowercase letter, and all following characters must be a dash,
      lowercase letter, or digit, except the last character, which cannot be a
      dash.
    EOT
  end

  newproperty(:port, parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      The TCP port number for the HTTP health check request. The default value
      is 80.
    EOT
  end

  newproperty(:request_path, parent: Google::Compute::Property::String) do
    desc <<-EOT
      The request path of the HTTP health check request. The default value is
      /.
    EOT
  end

  newproperty(:timeout_sec, parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      How long (in seconds) to wait before claiming failure. The default value
      is 5 seconds. It is invalid for timeoutSec to have greater value than
      checkIntervalSec.
    EOT
  end

  newproperty(:unhealthy_threshold,
              parent: Google::Compute::Property::Integer) do
    desc <<-EOT
      A so-far healthy instance will be marked unhealthy after this many
      consecutive failures. The default value is 2.
    EOT
  end
end
